#ifndef _SPELLFLAGS_H_
#define _SPELLFLAGS_H_

#define SPELLFLAG_REQTARGET    0
#define SPELLFLAG_OPTTARGET    1
#define SPELLFLAG_ONLYIND      2
#define SPELLFLAG_NOIND        3
#define SPELLFLAG_ONCORPSE     4
#define SPELLFLAG_MUSTSTAND    5
#define SPELLFLAG_PASSSTRING   6
#define SPELLFLAG_GIVEEXP      7
#define SPELLFLAG_ONSELF       8

#ifdef COMMANDS_C

char *spellflagnames[] = {"ReqTarget", "OptTarget", "OnlyInd", "NoInd", 
       "OnCorpse", "MustStand", "PassString", "GiveExp", "OnSelf", NULL};

#else

extern char *spellflagnames[];

#endif
#endif




